@@ -11,15 +11,15 @@
 #'
 #' @examples \dontrun{
 #' # Setup
-#' ckanr_setup(url = "http://demo.ckan.org/", key = getOption("ckan_demo_key"))
+#' ckanr_setup(url = "https://demo.ckan.org/", key = getOption("ckan_demo_key"))
 #'
 #' # get activity
 #' (res <- dashboard_activity_list())
 #' }
-dashboard_activity_list <- function(limit = 31, offset = 0, key = get_default_key(),
-  url = get_default_url(), as = 'list', ...) {
+dashboard_activity_list <- function(limit = 31, offset = 0,
+  url = get_default_url(), key = get_default_key(), as = 'list', ...) {
 
-  body <- list(limit = limit, offset = offset)
-  res <- ckan_POST(url, 'dashboard_activity_list', body = body, key = key, ...)
+  args <- list(limit = limit, offset = offset)
+  res <- ckan_GET(url, 'dashboard_activity_list', args, key = key, ...)
   switch(as, json = res, list = jsl(res), table = jsd(res))
 }
