@@ -12,17 +12,19 @@
 #'    names. Default: FALSE
 #' @template paging
 #' @template args
+#' @template key
 #' @examples \dontrun{
 #' group_list()
 #' group_list(as = 'json')
 #' group_list(as = 'table')
 #' }
 group_list <- function(offset = 0, limit = 31, sort = NULL, groups = NULL,
-                       all_fields = FALSE, url = get_default_url(), as = 'list', ...) {
+  all_fields = FALSE, url = get_default_url(), key = get_default_key(),
+  as = 'list', ...) {
 
-  body <- cc(list(offset = offset, limit = limit, sort = sort,
+  args <- cc(list(offset = offset, limit = limit, sort = sort,
                   groups = groups, all_fields = as_log(all_fields)))
-  res <- ckan_POST(url, 'group_list', body = body, ...)
+  res <- ckan_GET(url, 'group_list', args, key = key, ...)
   switch(as, json = res,
          list = lapply(jsl(res), as.ckan_group, url = url),
          table = jsd(res))
