@@ -7,7 +7,7 @@
 #' @template key
 #' @examples \dontrun{
 #' # Setup
-#' ckanr_setup(url = "http://demo.ckan.org", key = getOption("ckan_demo_key"))
+#' ckanr_setup(url = "https://demo.ckan.org", key = getOption("ckan_demo_key"))
 #'
 #' # Create a package
 #' (res <- group_create("hello-my-world2"))
@@ -21,10 +21,11 @@
 #' x <- list(title = "!hello world!", maintainer_email = "hello@@world.com")
 #' group_patch(x, id = grp)
 #' }
-group_patch <- function(x, id, key = get_default_key(),
-                           url = get_default_url(), as = 'list', ...) {
+group_patch <- function(x, id, url = get_default_url(), key = get_default_key(),
+  as = 'list', ...) {
+
   id <- as.ckan_group(id, url = url)
-  if (!is(x, "list")) {
+  if (!inherits(x, "list")) {
     stop("x must be of class list", call. = FALSE)
   }
   x$id <- id$id
