@@ -6,6 +6,7 @@
 #' @param include_datasets (logical) Include a list of the group's datasets.
 #'    Default: TRUE
 #' @template args
+#' @template key
 #' @details By default the help and success slots are dropped, and only the
 #'    result slot is returned. You can request raw json with \code{as = 'json'}
 #'    then parse yourself to get the help slot.
@@ -22,10 +23,11 @@
 #' group_show(res[[1]]$name, as = 'json')
 #' group_show(res[[1]]$name, as = 'table')
 #' }
-group_show <- function(id, include_datasets = TRUE,
-                       url = get_default_url(), as = 'list', ...) {
+group_show <- function(id, include_datasets = TRUE, url = get_default_url(),
+  key = get_default_key(), as = 'list', ...) {
+
   id <- as.ckan_group(id, url = url)
-  body <- cc(list(id = id$id, include_datasets = as_log(include_datasets)))
-  res <- ckan_POST(url, 'group_show', body = body, ...)
+  args <- cc(list(id = id$id, include_datasets = as_log(include_datasets)))
+  res <- ckan_GET(url, 'group_show', args, key = key, ...)
   switch(as, json = res, list = as_ck(jsl(res), "ckan_group"), table = jsd(res))
 }
