@@ -9,7 +9,7 @@
 #' @template key
 #' @examples \dontrun{
 #' # Setup
-#' ckanr_setup(url = "http://demo.ckan.org/", key = getOption("ckan_demo_key"))
+#' ckanr_setup(url = "https://demo.ckan.org/", key = getOption("ckan_demo_key"))
 #'
 #' # create a package and a related item
 #' res <- package_create("hello-venus2") %>%
@@ -21,8 +21,11 @@
 #' ## or with id itself:
 #' ## related_delete(res$id)
 #' }
-related_delete <- function(id, key = get_default_key(), url = get_default_url(), ...) {
+related_delete <- function(id, url = get_default_url(),
+  key = get_default_key(), ...) {
+
   id <- as.ckan_related(id, url = url)
-  tmp <- ckan_POST(url, 'related_delete', body = list(id = id$id), key = key, ...)
+  tmp <- ckan_POST(url, 'related_delete', body = list(id = id$id),
+    key = key, ...)
   jsonlite::fromJSON(tmp)$success
 }
