@@ -6,6 +6,7 @@
 #' @param order_by (character) Which field to sort the list by
 #'    (optional, default: 'name')
 #' @template args
+#' @template key
 #' @examples \dontrun{
 #' # all users
 #' user_list()
@@ -17,9 +18,11 @@
 #' user_list(q = "j", as = "table")
 #' user_list(q = "j", as = "json")
 #' }
-user_list <- function(q = NULL, order_by = NULL,
-                      url = get_default_url(), as = "list", ...) {
-  body <- cc(list(q = q, order_by = order_by))
-  res <- ckan_POST(url, 'user_list', body = body, ...)
-  switch(as, json = res, list = lapply(jsl(res), as.ckan_user), table = jsd(res))
+user_list <- function(q = NULL, order_by = NULL, url = get_default_url(),
+  key = get_default_key(), as = "list", ...) {
+
+  args <- cc(list(q = q, order_by = order_by))
+  res <- ckan_GET(url, 'user_list', args, key = key, ...)
+  switch(as, json = res, list = lapply(jsl(res), as.ckan_user),
+    table = jsd(res))
 }
