@@ -1,18 +1,24 @@
-context("changes")
+context("group_show")
+
+skip_on_cran()
+
 u <- get_test_url()
 g <- get_test_gid()
+if (g == "") {
+  g <- group_list(url = u, limit = 1)[[1]]$name
+}
 
-test_that("changes gives back expected class types", {
+test_that("group_show gives back expected class types", {
   check_ckan(u)
   check_group(u,g)
   a <- group_show(g, url=u)
 
   expect_is(a, "ckan_group")
-  expect_is(a[[1]], "list")
-  expect_is(a[[1]][[1]]$name, "character")
+  expect_is(a$name, "character")
+  expect_equal(a$id, g)
 })
 
-test_that("changes works giving back json output", {
+test_that("group_show works giving back json output", {
   check_ckan(u)
   check_group(u,g)
   b <- group_show(g, url=u, as='json')
@@ -23,7 +29,7 @@ test_that("changes works giving back json output", {
   expect_is(b_df$result, "list")
 })
 
-test_that("changes fails correctly", {
+test_that("group_show fails correctly", {
   check_ckan(u)
   expect_error(group_show("adf", url=u), "404 - Not Found Error")
   expect_error(group_show(limit = "Adf", url=u), "argument \"id\" is missing")
